@@ -6,7 +6,7 @@ from time import time
 
 from tqdm.notebook import tqdm
 from sklearn.metrics import mean_squared_error, accuracy_score, f1_score, precision_score,\
-                            recall_score, roc_auc_score, r2_score
+                            recall_score, roc_auc_score, r2_score, balanced_accuracy_score
 from sklearn.metrics import r2_score, explained_variance_score, mean_squared_error
 
 from sklearn.model_selection import train_test_split
@@ -59,34 +59,51 @@ from sklearn.neural_network import MLPRegressor
 import warnings
 warnings.filterwarnings("ignore") 
 
-def Select_Classifier(scoring, K_folds,X_train, X_test, y_train, y_test):
+def Select_Classifier(scoring, K_folds,X_train, X_test, y_train, y_test,MODELS):
 
-        models = []
         # models.append(('LR', LinearRegression()))
         # models.append(('Lasso', Lasso()))
         # models.append(('Ridge', Ridge()))
         # models.append(('EN', ElasticNet()))
-        models.append(('LGR', LogisticRegression(n_jobs=-1)))
-        # Boosting methods
-        models.append(('AB',  AdaBoostClassifier()))
-        models.append(('CART',DecisionTreeClassifier()))
-        # models.append(('LGBM', LGBMClassifier()))
-        models.append(('GBC', GradientBoostingClassifier()))
-        models.append(('XGBC', XGBClassifier(eval_metric=['logloss','auc','error'])))
-        # Bagging methods
-        models.append(('RFC', RandomForestClassifier()))
-        models.append(('ETC', ExtraTreeClassifier()))
-        # models.append(('LDA', LinearDiscriminantAnalysis()))
-        models.append(('KNN', KNeighborsClassifier(n_jobs=-1)))
-        models.append(('NB',  GaussianNB()))
-        models.append(('SVC', SVC()))
-        # Neural Network
-        models.append(('MLP', MLPClassifier()))
-        # others
-        models.append(('SGDC',SGDClassifier(n_jobs=-1)))
-        models.append(('GPC', GaussianProcessClassifier(n_jobs=-1)))
-        models.append(('PAC', PassiveAggressiveClassifier(n_jobs=-1)))
 
+
+        ML_MODELS = [('LGR', LogisticRegression(max_iter=10000,solver= 'saga',random_state=42,n_jobs=-1,class_weight='balanced')),
+                     ('AB',  AdaBoostClassifier()),
+                     ('CART',DecisionTreeClassifier(class_weight='balanced',random_state=42)),
+                      ('GBC', GradientBoostingClassifier(random_state=42)),
+                      ('XGBC', XGBClassifier(eval_metric=['logloss','auc','error'])),
+                      ('RFC', RandomForestClassifier(n_jobs=-1,random_state=42,class_weight='balanced')),
+                      ('ETC', ExtraTreeClassifier(random_state=42,class_weight='balanced')),
+                      ('KNN', KNeighborsClassifier(n_jobs=-1)),
+                      ('NB',  GaussianNB()),
+                      ('SVC', SVC(max_iter=10000,class_weight='balanced', random_state=42)),
+                      ('MLP', MLPClassifier()),
+                      ('SGDC',SGDClassifier(n_jobs=-1,class_weight='balanced', random_state=42)),
+                      ('GPC', GaussianProcessClassifier(n_jobs=-1,random_state=42)),
+                      ('PAC', PassiveAggressiveClassifier(n_jobs=-1,class_weight='balanced', random_state=42))
+                      ]
+
+        abb = []
+        for m in ML_MODELS:
+            abb.append(m[0])
+
+        for m in MODELS:
+            if m not in abb:
+                print('ERROR: {m} is not a valid model!'.format(m=m))
+            else:
+                pass
+
+
+        models = []
+        for index,m in enumerate(ML_MODELS):
+            # print(index, m[0])
+            for M in MODELS:
+                if M == m[0]:
+                    models.append(ML_MODELS[index])
+                else:
+                    pass
+        
+   
         names = []
         kfold_results = []
         test_results = []
@@ -94,6 +111,8 @@ def Select_Classifier(scoring, K_folds,X_train, X_test, y_train, y_test):
 
         if scoring == 'accuracy':
             metrics = accuracy_score      
+        if scoring == 'balanced_accuracy':
+            metrics = balanced_accuracy_score   
         elif scoring == 'f1_score':
             metrics = f1_score
         elif scoring == 'precision':
